==> centreon-web-23.04.26.tar.gz: centreon-web-23.04.26/src/Core/Infrastructure/RealTime/Api/FindHost/FindHostController.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */
declare(strict_types=1);

namespace Core\Infrastructure\RealTime\Api\FindHost;

use Centreon\Application\Controller\AbstractController;
use Core\Application\RealTime\UseCase\FindHost\FindHost;
use Core\Application\RealTime\UseCase\FindHost\FindHostPresenterInterface;

class FindHostController extends AbstractController
{
    /**
     * @param int $hostId
     * @param FindHost $useCase
     * @param FindHostPresenterInterface $presenter
     * @return object
     */
    public function __invoke(
        int $hostId,
        FindHost $useCase,
        FindHostPresenterInterface $presenter
    ): object {
        /**
         * Deny access if user has no rights on the real time
         */
        $this->denyAccessUnlessGrantedForApiRealtime();

        $useCase($hostId, $presenter);
        return $presenter->show();
    }
}

==> centreon-web-23.10.28.tar.gz: centreon-web-23.10.28/src/Core/Infrastructure/RealTime/Api/FindHost/FindHostController.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\RealTime\Api\FindHost;

use Centreon\Application\Controller\AbstractController;
use Core\Application\RealTime\UseCase\FindHost\FindHost;
use Core\Application\RealTime\UseCase\FindHost\FindHostPresenterInterface;

class FindHostController extends AbstractController
{
    /**
     * @param int $hostId
     * @param FindHost $useCase
     * @param FindHostPresenterInterface $presenter
     *
     * @return object
     */
    public function __invoke(
        int $hostId,
        FindHost $useCase,
        FindHostPresenterInterface $presenter
    ): object {
        /**
         * Deny access if user has no rights on the real time.
         */
        $this->denyAccessUnlessGrantedForApiRealtime();

        $useCase($hostId, $presenter);

        return $presenter->show();
    }
}
